==> bit-bin-13.0.5-dev.6.tgz: package/src/scope/version-dependencies.js <==
/** @flow */
import ComponentWithDependencies from './component-dependencies';
import ComponentVersion from './component-version';
import ComponentObjects from './component-objects';
import Repository from './objects/repository';
import BitMap from '../consumer/bit-map';

export default class VersionDependencies {
  component: ComponentVersion;
  dependencies: ComponentVersion[];
  devDependencies: ComponentVersion[];
  compilerDependencies: ComponentVersion[];
  testerDependencies: ComponentVersion[];
  allDependencies: ComponentVersion[];
  sourceScope: ?string;

  constructor(
    component: ComponentVersion,
    dependencies: ComponentVersion[],
    devDependencies: ComponentVersion[],
    compilerDependencies: ComponentVersion[],
    testerDependencies: ComponentVersion[],
    sourceScope: string
  ) {
    this.component = component;
    this.dependencies = dependencies;
    this.devDependencies = devDependencies;
    this.compilerDependencies = compilerDependencies;
    this.testerDependencies = testerDependencies;
    this.allDependencies = [
      ...this.dependencies,
      ...this.devDependencies,
      ...this.compilerDependencies,
      ...this.testerDependencies
    ];
    this.sourceScope = sourceScope;
  }

  async toConsumer(repo: Repository, bitMap?: BitMap, manipulateDir?: boolean): Promise<ComponentWithDependencies> {
    const dependenciesP = Promise.all(this.dependencies.map(dep => dep.toConsumer(repo)));
    const devDependenciesP = Promise.all(this.devDependencies.map(dep => dep.toConsumer(repo)));
    const compilerDependenciesP = Promise.all(this.compilerDependencies.map(dep => dep.toConsumer(repo)));
    const testerDependenciesP = Promise.all(this.testerDependencies.map(dep => dep.toConsumer(repo)));
    const componentP = this.component.toConsumer(repo, bitMap, manipulateDir);
    const [component, dependencies, devDependencies, compilerDependencies, testerDependencies] = await Promise.all([
      componentP,
      dependenciesP,
      devDependenciesP,
      compilerDependenciesP,
      testerDependenciesP
    ]);
    return new ComponentWithDependencies({
      component,
      dependencies,
      devDependencies,
      compilerDependencies,
      testerDependencies
    });
  }

  toObjects(repo: Repository): Promise<ComponentObjects> {
    const depsP = Promise.all(this.allDependencies.map(dep => dep.toObjects(repo)));
    const compP = this.component.toObjects(repo);

    return Promise.all([compP, depsP]).then(([component, dependencies]) => {
      const flattened = dependencies.reduce((array, compObjects) => {
        array.push(...compObjects.objects.concat([compObjects.component]));
        return array;
      }, []);

      return new ComponentObjects(component.component, flattened.concat(component.objects));
    });
  }
}

==> bit-bin-14.0.2.tgz: package/src/scope/version-dependencies.js <==
/** @flow */
import ComponentWithDependencies from './component-dependencies';
import ComponentVersion from './component-version';
import ComponentObjects from './component-objects';
import Repository from './objects/repository';
import type { ManipulateDirItem } from '../consumer/component-ops/manipulate-dir';

export default class VersionDependencies {
  component: ComponentVersion;
  dependencies: ComponentVersion[];
  devDependencies: ComponentVersion[];
  compilerDependencies: ComponentVersion[];
  testerDependencies: ComponentVersion[];
  allDependencies: ComponentVersion[];
  sourceScope: ?string;

  constructor(
    component: ComponentVersion,
    dependencies: ComponentVersion[],
    devDependencies: ComponentVersion[],
    compilerDependencies: ComponentVersion[],
    testerDependencies: ComponentVersion[],
    sourceScope: string
  ) {
    this.component = component;
    this.dependencies = dependencies;
    this.devDependencies = devDependencies;
    this.compilerDependencies = compilerDependencies;
    this.testerDependencies = testerDependencies;
    this.allDependencies = [
      ...this.dependencies,
      ...this.devDependencies,
      ...this.compilerDependencies,
      ...this.testerDependencies
    ];
    this.sourceScope = sourceScope;
  }

  async toConsumer(repo: Repository, manipulateDirData: ?(ManipulateDirItem[])): Promise<ComponentWithDependencies> {
    const depToConsumer = dep => dep.toConsumer(repo, manipulateDirData);
    const dependenciesP = Promise.all(this.dependencies.map(depToConsumer));
    const devDependenciesP = Promise.all(this.devDependencies.map(depToConsumer));
    const compilerDependenciesP = Promise.all(this.compilerDependencies.map(depToConsumer));
    const testerDependenciesP = Promise.all(this.testerDependencies.map(depToConsumer));
    const componentP = this.component.toConsumer(repo, manipulateDirData);
    const [component, dependencies, devDependencies, compilerDependencies, testerDependencies] = await Promise.all([
      componentP,
      dependenciesP,
      devDependenciesP,
      compilerDependenciesP,
      testerDependenciesP
    ]);
    return new ComponentWithDependencies({
      component,
      dependencies,
      devDependencies,
      compilerDependencies,
      testerDependencies
    });
  }

  toObjects(repo: Repository): Promise<ComponentObjects> {
    const depsP = Promise.all(this.allDependencies.map(dep => dep.toObjects(repo)));
    const compP = this.component.toObjects(repo);

    return Promise.all([compP, depsP]).then(([component, dependencies]) => {
      const flattened = dependencies.reduce((array, compObjects) => {
        array.push(...compObjects.objects.concat([compObjects.component]));
        return array;
      }, []);

      return new ComponentObjects(component.component, flattened.concat(component.objects));
    });
  }
}
